<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//cs_CZ

$LANG=array();


$LANG['backup'][0]="Výpis SQL"; 
$LANG['backup'][1]="Výpis XML"; 
$LANG['backup'][11]="Velikost"; 
$LANG['backup'][13]="Zobrazit/Stáhnout"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Smazat tento soubor"; 
$LANG['backup'][18]="Záloha databáze"; 
$LANG['backup'][19]="Nyní"; 
$LANG['backup'][21]="Soubor již existuje"; 
$LANG['backup'][22]="Nemohu nalézt data"; 
$LANG['backup'][23]="Chyba Mysql začíná na"; 
$LANG['backup'][24]="Automatické přesměrování, jinak klikněte"; 

$LANG['bookmark'][1]="záložka"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Zatím nemáte žádné záložky."; 
$LANG['bookmark'][4]="Nová záložka"; 
$LANG['bookmark'][5]="Public bookmarks"; 
$LANG['bookmark'][6]="Použít defaultně"; 

$LANG['buttons'][0]="Hledat"; 
$LANG['buttons'][2]="Odeslat"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Instalovat"; 
$LANG['buttons'][5]="Odinstalovat"; 
$LANG['buttons'][6]="Smazat"; 
$LANG['buttons'][7]="Aktualizovat"; 
$LANG['buttons'][8]="Přidat"; 
$LANG['buttons'][9]="Připojit"; 
$LANG['buttons'][10]="Odpojit"; 
$LANG['buttons'][11]="Další"; 
$LANG['buttons'][12]="Předchozí"; 
$LANG['buttons'][13]="Zpět"; 
$LANG['buttons'][14]="Aktualizovat"; 
$LANG['buttons'][15]="Pracovní plán"; 
$LANG['buttons'][16]="Formulář"; 
$LANG['buttons'][17]="Invertovat označení"; 
$LANG['buttons'][18]="Zaškrtnout vše"; 
$LANG['buttons'][19]="Odškrtnout vše"; 
$LANG['buttons'][20]="Přesunout"; 
$LANG['buttons'][21]="Obnovit"; 
$LANG['buttons'][22]="Vyčistit"; 
$LANG['buttons'][23]="Zobrazit"; 
$LANG['buttons'][24]="Nahoru"; 
$LANG['buttons'][25]="Dolů"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Export"; 
$LANG['buttons'][32]="Konec"; 
$LANG['buttons'][33]="Spustit"; 
$LANG['buttons'][34]="Zrušit"; 
$LANG['buttons'][37]="Import"; 
$LANG['buttons'][38]="Odemknout"; 
$LANG['buttons'][39]="Nahradit"; 
$LANG['buttons'][40]="Zobrazit všechny"; 
$LANG['buttons'][41]="Aktivovat"; 
$LANG['buttons'][42]="Deaktivovat"; 
$LANG['buttons'][43]="Procházet"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Předchozí"; 
$LANG['buttons'][47]="Další"; 
$LANG['buttons'][48]="Přesun"; 
$LANG['buttons'][49]="Zachovat"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Uložit"; 
$LANG['buttons'][52]="Otevřít"; 
$LANG['buttons'][53]="Vyčistit"; 
$LANG['buttons'][55]="První"; 
$LANG['buttons'][56]="Poslední"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="Ne"; 
$LANG['calendarD'][1]="Po"; 
$LANG['calendarD'][2]="Út"; 
$LANG['calendarD'][3]="St"; 
$LANG['calendarD'][4]="Čt"; 
$LANG['calendarD'][5]="Pá"; 
$LANG['calendarD'][6]="So"; 

$LANG['calendarDay'][0]="Neděle"; 
$LANG['calendarDay'][1]="Pondělí"; 
$LANG['calendarDay'][2]="Úterý"; 
$LANG['calendarDay'][3]="Středa"; 
$LANG['calendarDay'][4]="Čtvrtek"; 
$LANG['calendarDay'][5]="Pátek"; 
$LANG['calendarDay'][6]="Sobota"; 

$LANG['calendarM'][0]="Leden"; 
$LANG['calendarM'][1]="Únor"; 
$LANG['calendarM'][2]="Březen"; 
$LANG['calendarM'][3]="Duben"; 
$LANG['calendarM'][4]="Květen"; 
$LANG['calendarM'][5]="Červen"; 
$LANG['calendarM'][6]="Červenec"; 
$LANG['calendarM'][7]="Srpen"; 
$LANG['calendarM'][8]="Září"; 
$LANG['calendarM'][9]="Říjen"; 
$LANG['calendarM'][10]="Listopad"; 
$LANG['calendarM'][11]="Prosinec"; 

$LANG['cartridges'][0]="Náplň do tiskárny"; 
$LANG['cartridges'][7]="Nebyla nalezená žádná náplň"; 
$LANG['cartridges'][9]="Bez náplně"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Typ náplně"; 
$LANG['cartridges'][13]="Nová"; 
$LANG['cartridges'][14]="Použito"; 
$LANG['cartridges'][15]="Použité"; 
$LANG['cartridges'][16]="Náplň(e)"; 
$LANG['cartridges'][20]="Nová"; 
$LANG['cartridges'][21]="Použito"; 
$LANG['cartridges'][22]="Použité"; 
$LANG['cartridges'][24]="Přidat datum"; 
$LANG['cartridges'][27]="Na"; 
$LANG['cartridges'][29]="Konec životnosti"; 
$LANG['cartridges'][32]="Modely kompatibilních tiskáren"; 
$LANG['cartridges'][33]="Použité náplně"; 
$LANG['cartridges'][34]="Žádná volná náplň"; 
$LANG['cartridges'][35]="Použité náplně"; 
$LANG['cartridges'][37]="Páska"; 
$LANG['cartridges'][39]="Počítadlo tiskárny"; 
$LANG['cartridges'][40]="Průměrný čas požadavku"; 
$LANG['cartridges'][41]="Průměrný čas užití"; 
$LANG['cartridges'][42]="Průměrný počet vytisknutých stránek"; 

$LANG['central'][2]="Poslední"; 
$LANG['central'][4]="Žádná událost"; 
$LANG['central'][5]="Domů"; 
$LANG['central'][6]="Odhlásit"; 
$LANG['central'][7]="Nápověda"; 
$LANG['central'][8]="Přidání"; 
$LANG['central'][9]="Stav zpracování vašich požadavků"; 
$LANG['central'][10]="Nové požadavky"; 
$LANG['central'][12]="Vlastní pohled"; 
$LANG['central'][13]="Globální pohled"; 
$LANG['central'][14]="Skupinový Pohled"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Ne"; 
$LANG['choice'][1]="Ano"; 

$LANG['common'][0]="Bez jména"; 
$LANG['common'][1]="Položka"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Výrobce"; 
$LANG['common'][6]="Jméno šablony"; 
$LANG['common'][7]="Zvolit šablonu"; 
$LANG['common'][8]="Spravovat šablony"; 
$LANG['common'][9]="Přidat šablonu"; 
$LANG['common'][10]="Zodpovědnost technika"; 
$LANG['common'][11]="Omezený pohled"; 
$LANG['common'][12]="Nastavení"; 
$LANG['common'][13]="Šablona"; 
$LANG['common'][14]="Šablony"; 
$LANG['common'][15]="Umístění"; 
$LANG['common'][16]="Jméno"; 
$LANG['common'][17]="Typ"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Sériové číslo"; 
$LANG['common'][20]="Inventární číslo"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="Operace byla úspěšná"; 
$LANG['common'][24]="Žádná položka nebyla vybrána nebo je špatně definovaná operace"; 
$LANG['common'][25]="Komentáře"; 
$LANG['common'][26]="Poslední aktualizace"; 
$LANG['common'][27]="Datum"; 
$LANG['common'][28]="Smazáno"; 
$LANG['common'][29]="Pluginy"; 
$LANG['common'][30]="Nová položka"; 
$LANG['common'][31]="Prázdná šablona"; 
$LANG['common'][32]="Charakteristiky"; 
$LANG['common'][33]="Celkem"; 
$LANG['common'][34]="Uživatel"; 
$LANG['common'][35]="Skupina"; 
$LANG['common'][36]="Kategorie"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Zdvojit položku tolikrát kolik je připojení"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Upozornění na email"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Jméno"; 
$LANG['common'][44]="Výchozí hodnota(y)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="Postup"; 
$LANG['common'][48]="Příjmení"; 
$LANG['common'][49]="Žádný"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="Celé jméno"; 
$LANG['common'][52]="Server"; 
$LANG['common'][53]="Seznam"; 
$LANG['common'][54]="Položka nenalezena"; 
$LANG['common'][55]="Opravdu si přejete smazat tuto položku?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Název"; 
$LANG['common'][58]="Maximální hodnota"; 
$LANG['common'][59]="Globální"; 
$LANG['common'][60]="Aktivní"; 
$LANG['common'][61]="Neznámá chyba"; 
$LANG['common'][62]="Ostatní"; 
$LANG['common'][63]="Chyba(y)"; 
$LANG['common'][64]="Manager"; 
$LANG['common'][65]="Rozhraní"; 
$LANG['common'][66]="Všechny"; 
$LANG['common'][67]="Ostatní"; 
$LANG['common'][68]="Na šířku"; 
$LANG['common'][69]="Na výšku"; 
$LANG['common'][70]="Položka byla přidána"; 
$LANG['common'][71]="Položka byla změněna"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Item successfully restored"; 
$LANG['common'][75]="No right to make this item recursive in this entity"; 
$LANG['common'][76]="Public"; 
$LANG['common'][77]="Private"; 
$LANG['common'][78]="Set public"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="Během nahrávání..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Flag change forbidden. Linked items found."; 
$LANG['common'][85]="Změnit viditelnost podřízených objektů"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="Nová karta"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Jednotka"; 
$LANG['computers'][1]="Volno %"; 
$LANG['computers'][2]="Volné místo"; 
$LANG['computers'][3]="Hlavní velikost"; 
$LANG['computers'][4]="Souborový systém"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Přidat disk"; 
$LANG['computers'][8]="Jednotky"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Vloženo"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Žádný připojený monitor"; 
$LANG['computers'][38]="Žádná připojená tiskárna"; 
$LANG['computers'][39]="Tiskárny"; 
$LANG['computers'][40]="Monitor(y)"; 
$LANG['computers'][46]="Zařízení"; 
$LANG['computers'][47]="Žádné připojené zařízení"; 
$LANG['computers'][48]="Umístění bylo aktualizováno. Připojené položky byly přesunuty na stejné umístění."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Uživatel nebo skupina aktualizována. Připojené položky byly přesunuty se stejnými hodnotami."; 
$LANG['computers'][51]="Forma aktualizace"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Balíček záplat"; 
$LANG['computers'][54]="Žádný telefon není připojen"; 
$LANG['computers'][55]="Telefon(y)"; 
$LANG['computers'][56]="Status updated. The connected items have been updated using this status."; 

$LANG['connect'][0]="Přímá připojení"; 
$LANG['connect'][1]="Není připojeno"; 
$LANG['connect'][15]="Automatická aktualizace následujících položek"; 
$LANG['connect'][16]="Upozornění !! Následující dvě HW položky nesouhlasí"; 

$LANG['consumables'][0]="Spotřební materiál"; 
$LANG['consumables'][1]="Ve fondu"; 
$LANG['consumables'][2]="Reference"; 
$LANG['consumables'][7]="Nebylo nalezeno žádné spotřební zboží"; 
$LANG['consumables'][9]="Žádný spotřební materiál"; 
$LANG['consumables'][12]="Typ spotřebního materiálu"; 
$LANG['consumables'][13]="Nová"; 
$LANG['consumables'][15]="Použito"; 
$LANG['consumables'][16]="Spotřební materiál(y)"; 
$LANG['consumables'][20]="Nová"; 
$LANG['consumables'][22]="Použito"; 
$LANG['consumables'][23]="Stav"; 
$LANG['consumables'][26]="Použít datum"; 
$LANG['consumables'][32]="Dát"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Umístění inventáře"; 
$LANG['consumables'][37]="Zpět na inventář"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Přidat novou komponentu"; 
$LANG['devices'][1]="Pevný disk"; 
$LANG['devices'][2]="Grafická karta"; 
$LANG['devices'][3]="Síťová karta"; 
$LANG['devices'][4]="Procesor"; 
$LANG['devices'][5]="Systémová deska"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Zvuková karta"; 
$LANG['devices'][19]="Disky"; 
$LANG['devices'][20]="Řadiče"; 
$LANG['devices'][21]="Další komponenty"; 
$LANG['devices'][22]="Skříně"; 
$LANG['devices'][23]="Zdroj energie"; 
$LANG['devices'][24]="standardně"; 
$LANG['devices'][25]="Přidat komponentu"; 
$LANG['devices'][26]="Smazat komponentu"; 

$LANG['device_case'][0]="Velikost"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Schopnost psát"; 
$LANG['device_drive'][1]="Rychlost"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Cache"; 
$LANG['device_hdd'][4]="Kapacita"; 

$LANG['device_iface'][0]="Datový tok"; 
$LANG['device_iface'][2]="Mac adresa"; 

$LANG['device_moboard'][0]="Čipová sada"; 

$LANG['device_power'][0]="Zdroj"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekvence"; 
$LANG['device_ram'][2]="Velikost"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Soubor"; 
$LANG['document'][3]="Hlavička"; 
$LANG['document'][4]="Typ MIME"; 
$LANG['document'][7]="Typ dokumentu"; 
$LANG['document'][9]="Rozšíření"; 
$LANG['document'][10]="Ikona"; 
$LANG['document'][11]="Autorizované stažení"; 
$LANG['document'][15]="Stáhnout"; 
$LANG['document'][16]="Přidat dokument"; 
$LANG['document'][18]="Dokument"; 
$LANG['document'][19]="Přiřazené položky"; 
$LANG['document'][21]="Přiřazené dokumenty"; 
$LANG['document'][22]="Aktuální soubor"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Mazání souboru bylo úspěšné"; 
$LANG['document'][25]="Chyba při mazání souboru"; 
$LANG['document'][26]="Soubor je platný. Upload byl úspěšný."; 
$LANG['document'][27]="Možný útok při uploadu nebo byl soubor příliš velký. Přesunutí dočasného souboru selhalo."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Chyba při vytváření adresáře"; 
$LANG['document'][30]="Ověřte, že máte správně nastaveno oprávnění"; 
$LANG['document'][31]="Adresář pro dokumenty neexistuje"; 
$LANG['document'][32]="Neplatný typ souboru"; 
$LANG['document'][33]="Webový odkaz"; 
$LANG['document'][34]="Vytvořit adresář"; 
$LANG['document'][35]="Adresář pro upload neexistuje"; 
$LANG['document'][36]="Použít soubor na FTP"; 
$LANG['document'][37]="Žádný soubor není k dispozici"; 
$LANG['document'][38]="Soubor nenalezen"; 
$LANG['document'][39]="Přesunutí dokumentu bylo úspěšné"; 
$LANG['document'][40]="Přesun souboru selhal"; 
$LANG['document'][41]="Kopírování dokumentu bylo úspěšné"; 
$LANG['document'][42]="Přidán pomocí"; 
$LANG['document'][43]="Neznámý soubor"; 
$LANG['document'][44]="Neplatný název souboru"; 
$LANG['document'][45]="Neoprávněný přístup k tomuto souboru"; 
$LANG['document'][46]="Chyba při odesílání souboru (pravděpodobně z důvodu velikosti)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Objekt"; 
$LANG['entity'][2]="Osoba root"; 
$LANG['entity'][3]="Přiřadit objektu"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Automatické přiřazení uživatele"; 
$LANG['entity'][7]="stromová struktura"; 
$LANG['entity'][8]="Dle předmětu"; 
$LANG['entity'][9]="Podřízené objekty"; 
$LANG['entity'][10]="Select the desired entity"; 
$LANG['entity'][11]="to see the entity and its sub-entities"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Služby"; 
$LANG['event'][3]="Úroveň"; 
$LANG['event'][4]="Zpráva"; 
$LANG['event'][18]="Položka"; 
$LANG['event'][19]="Aktualizovat"; 
$LANG['event'][20]="Žádná historie"; 

$LANG['financial'][1]="Smlouva"; 
$LANG['financial'][2]="Je živý"; 
$LANG['financial'][3]="Finanční informace"; 
$LANG['financial'][4]="Množství"; 
$LANG['financial'][5]="Cena"; 
$LANG['financial'][6]="Typ smlouvy"; 
$LANG['financial'][8]="Trvání"; 
$LANG['financial'][9]="rok(ů)"; 
$LANG['financial'][10]="Poznámka"; 
$LANG['financial'][11]="Opakování faktury"; 
$LANG['financial'][13]="Číslo účetnictví"; 
$LANG['financial'][14]="Datum koupě"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Informace o záruce"; 
$LANG['financial'][18]="Počet objednávek"; 
$LANG['financial'][19]="Dodací formulář"; 
$LANG['financial'][20]="Imobilizační číslo"; 
$LANG['financial'][21]="Hodnota"; 
$LANG['financial'][22]="Typ autorizace"; 
$LANG['financial'][23]="Trvání autorizace"; 
$LANG['financial'][24]="Přidat kontakt..."; 
$LANG['financial'][25]="Přidat dodavatele..."; 
$LANG['financial'][26]="Dodavatel"; 
$LANG['financial'][30]="Fax"; 
$LANG['financial'][33]="Přidat kontakt"; 
$LANG['financial'][36]="Přidat kontrakt"; 
$LANG['financial'][42]="Komerční"; 
$LANG['financial'][43]="Technik"; 
$LANG['financial'][44]="Adresa"; 
$LANG['financial'][45]="Webová stránka"; 
$LANG['financial'][46]="Přiřazené kontakty"; 
$LANG['financial'][47]="Lineární"; 
$LANG['financial'][48]="Degresivní"; 
$LANG['financial'][50]="Půjčky"; 
$LANG['financial'][51]="Rentování"; 
$LANG['financial'][52]="Pronájmy"; 
$LANG['financial'][53]="Pojištění"; 
$LANG['financial'][54]="Podpora hardwaru"; 
$LANG['financial'][55]="Podpora programu"; 
$LANG['financial'][56]="Poskytované služby"; 
$LANG['financial'][57]="měsíc"; 
$LANG['financial'][59]="Hodiny zákroku"; 
$LANG['financial'][60]="za týden"; 
$LANG['financial'][61]="v sobotu"; 
$LANG['financial'][62]="Neděle a prázdniny"; 
$LANG['financial'][65]="Přiřazení dodavatelé"; 
$LANG['financial'][66]="Přiřazené smlouvy"; 
$LANG['financial'][68]="Aktivovat informace o financích"; 
$LANG['financial'][69]="Pravidelnost smlouvy"; 
$LANG['financial'][76]="Počáteční datum"; 
$LANG['financial'][77]="Autorizační koeficient"; 
$LANG['financial'][78]="Hodnota konce záruky"; 
$LANG['financial'][79]="Označení typu třetích stran"; 
$LANG['financial'][80]="Záruka končí"; 
$LANG['financial'][81]="Účetnictví"; 
$LANG['financial'][82]="Číslo faktury"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="Tohoto typu položky, informace o financích jsou pouze ukázkou elementu, které můžete přidat."; 
$LANG['financial'][85]="Požadovaná položka nebyla nalezena"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Rozpočet"; 
$LANG['financial'][88]="Platnost do:"; 
$LANG['financial'][89]="TCO (hodnota + cena sledování)"; 
$LANG['financial'][90]="Měsíční TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Vypršení smlouvy - posledních 30 dnů"; 
$LANG['financial'][94]="Vypršení smlouvy v méně jak 7 dnech"; 
$LANG['financial'][95]="Vypršení smlouvy v méně jak 30 dnech"; 
$LANG['financial'][96]="Smlouvy, na které budete upozornění v příštích 7 dnech"; 
$LANG['financial'][97]="Smlouvy, na které budete upozorněni v příštích 30 dnech"; 
$LANG['financial'][98]="Datum ukončení"; 
$LANG['financial'][99]="Datum ukončení + poznámka"; 
$LANG['financial'][100]="Poštovní kód"; 
$LANG['financial'][101]="Město"; 
$LANG['financial'][102]="Stav"; 
$LANG['financial'][103]="Země"; 
$LANG['financial'][104]="Přiřazené položky"; 
$LANG['financial'][105]="nevyslovený"; 
$LANG['financial'][106]="Spěšně"; 
$LANG['financial'][107]="Obnova"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="hodin"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Velmi vysoká"; 
$LANG['help'][4]="Vysoká"; 
$LANG['help'][5]="Střední"; 
$LANG['help'][6]="Nízká"; 
$LANG['help'][7]="Velmi nízká"; 
$LANG['help'][8]="Informovat mě o provedených akcích"; 
$LANG['help'][11]="Můj email"; 
$LANG['help'][14]="Odeslat zprávu"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Your message has been sent successfully, your request is on file."; 
$LANG['help'][19]="Thank you for using our automatic helpdesk system."; 
$LANG['help'][22]="Hledat ID počítače"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Typ hardwaru"; 
$LANG['help'][25]="Počítač"; 
$LANG['help'][26]="Síťové zařízení"; 
$LANG['help'][27]="Tiskárna"; 
$LANG['help'][28]="Sledovat"; 
$LANG['help'][29]="Zařízení"; 
$LANG['help'][30]="Obecná"; 
$LANG['help'][31]="Software"; 
$LANG['help'][35]="Phone"; 
$LANG['help'][40]="Není vyplněn název."; 
$LANG['help'][41]="Není zvolena kategorie."; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="Instalace nebo aktualizace GLPI"; 
$LANG['install'][1]="Pro úplně novou instalaci GLPI zvolte 'Instalovat'."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="Instalace"; 
$LANG['install'][4]="Aktualizovat"; 
$LANG['install'][5]="Zkontrolovat kompatibilitu vašeho prostředí a systému GLPI"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Výsledky"; 
$LANG['install'][8]="Testování překladače PHP"; 
$LANG['install'][9]="You must install at least PHP5."; 
$LANG['install'][10]="GLPI is not compatible with the option zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP je verze 5.x a vyšší - Výborně!"; 
$LANG['install'][12]="Test sezení"; 
$LANG['install'][13]="Váš překladač PHP není zkompilován s podporou sezení (sessions)!"; 
$LANG['install'][14]="Podpora sezení je k dispozici - výborně !"; 
$LANG['install'][15]="Ujistěte se, že byla v souboru php.ini aktivována podpora sezení"; 
$LANG['install'][16]="Kontroluji oprávnění zápisu pro soubory s výpisy"; 
$LANG['install'][17]="Není možné vytvořit tento soubor."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="Soubor byl vytvořen, ale není ho možné smazat."; 
$LANG['install'][20]="Vytvoření a smazání souboru a adresáře bylo provedeno - výborně!"; 
$LANG['install'][21]="Kontroluji oprávnění zápisu pro soubory dokumentů"; 
$LANG['install'][22]="Soubor byl vytvořen"; 
$LANG['install'][23]="Kontroluji oprávnění zápisu pro soubory s nastavením"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Pokračovat ?"; 
$LANG['install'][26]="Pokračovat"; 
$LANG['install'][27]="Zkusit znova"; 
$LANG['install'][28]="Nastavení připojení k databázi"; 
$LANG['install'][29]="Parametry připojení k databázi"; 
$LANG['install'][30]="Server Mysql"; 
$LANG['install'][31]="Uživatel Mysql"; 
$LANG['install'][32]="Heslo Mysql"; 
$LANG['install'][34]="Test připojení k databázi"; 
$LANG['install'][35]="Nemohu se připojit do databáze"; 
$LANG['install'][36]="Server odpověděl"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Zvolte prosím databázi:"; 
$LANG['install'][39]="Vytvořit novou databázi nebo použít stávající:"; 
$LANG['install'][40]="Zvolte prosím aktualizovanou databázi:"; 
$LANG['install'][41]="Není možné použít databázi:"; 
$LANG['install'][43]="OK - databáze byla inicializována"; 
$LANG['install'][47]="Není možné zapsat do souboru s nastavením databáze"; 
$LANG['install'][48]="Chyba při vytváření databáze !"; 
$LANG['install'][49]="Nezvolili jste databázi !"; 
$LANG['install'][50]="Kontroluji oprávnění zápisu pro soubory sezení"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Testování zápisu souborů logu"; 
$LANG['install'][55]="Instalace byla dokončena"; 
$LANG['install'][57]="Výchozí přihlášení / hesla jsou:"; 
$LANG['install'][58]="glpi/glpi (pro účet administrátora)"; 
$LANG['install'][59]="tech/tech pro účet technika"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="Použít GLPI"; 
$LANG['install'][65]="test rozšíření magic_quotes_sybase"; 
$LANG['install'][66]="GLPI nebude fungovat s volbou magic_quotes_sybase; Vypněte ji prosím a zkuste to znovu"; 
$LANG['install'][67]="Volba magic_quotes_sybase není na vašem serveru aktivní - výborně !"; 
$LANG['install'][68]="Test session auto start"; 
$LANG['install'][69]="session.auto_start is activated. See .htaccess file in the GLPI root for more information."; 
$LANG['install'][70]="Nemohu vytvořit soubor s databázovým připojením, ověřte prosím oprávnění k souboru."; 
$LANG['install'][71]="Test rozšíření Mysql"; 
$LANG['install'][72]="PHP musíte zkompilovat s rozšířením Mysql."; 
$LANG['install'][73]="OK - funkce mysql_query() existuje - Výborně!"; 
$LANG['install'][74]="Test zda se používá Session_use_trans_sid"; 
$LANG['install'][75]="V php.ini musíte deaktivovat volbu Session_use_trans_id."; 
$LANG['install'][76]="OK - sezení funguje (bez problému s trans_id) - Výborně!"; 
$LANG['install'][77]="Krok"; 
$LANG['install'][81]="Počátek instalace"; 
$LANG['install'][82]="Databáze vytvořena"; 
$LANG['install'][85]="Funkce byly nalazeny - výborně !"; 
$LANG['install'][86]="Test alokované paměti"; 
$LANG['install'][87]="Alokovaná paměť:"; 
$LANG['install'][88]="Obvykle se pro GLPI vyžaduje minimálně 64Mb."; 
$LANG['install'][89]="Výborně !"; 
$LANG['install'][90]="Zkuste zvýšit parametr memory_limit v souboru php.ini."; 
$LANG['install'][91]="Alokovaná paměť > 64M"; 
$LANG['install'][92]="Licence"; 
$LANG['install'][93]="Přečetl jsem si licenční ujednání napsané výše a SOUHLASÍM s ním."; 
$LANG['install'][94]="Přečetl jsem si licenční ujednání uvedené výše a NESOUHLASÍM s ním"; 
$LANG['install'][95]="Neomezená paměť"; 
$LANG['install'][96]="Neomezená paměť"; 
$LANG['install'][97]="Zkontrolujte oprávnění zápisu do adresáře:"; 
$LANG['install'][99]="Kontroluji oprávnění zápisu pro soubory s cache pamětí"; 
$LANG['install'][100]="Adresář není možno vytvořit"; 
$LANG['install'][101]="Adresář byl vytvořen, ale není ho možno odstranit."; 
$LANG['install'][102]="Test json functions"; 
$LANG['install'][103]="GLPI nemůže správně pracovat bez funkcí json_encode a json_decode"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="zadavatel"; 
$LANG['job'][4]="Žadatel"; 
$LANG['job'][5]="Přiřazeno k"; 
$LANG['job'][6]="Technik"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Popište problém/akci"; 
$LANG['job'][12]="Žádný následovník tohoto požadavku."; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Následovníci emailu"; 
$LANG['job'][20]="Doba trvání celkem"; 
$LANG['job'][21]="Hodin"; 
$LANG['job'][22]="Minut"; 
$LANG['job'][29]="Přidat nové sledování"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Trvání"; 
$LANG['job'][32]="Žádný"; 
$LANG['job'][33]="Vyprázdnit popis"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Plánování"; 
$LANG['job'][37]="Souhrn"; 
$LANG['job'][38]="Úkol"; 
$LANG['job'][39]="Aktualizovat sledování"; 
$LANG['job'][40]="Časová náročnost"; 
$LANG['job'][41]="Pevná cena"; 
$LANG['job'][42]="Cena materiálu"; 
$LANG['job'][43]="Celková cena"; 
$LANG['job'][44]="Požadovat příčinu"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Stav"; 
$LANG['joblist'][1]="Získané úkoly"; 
$LANG['joblist'][2]="Priorita"; 
$LANG['joblist'][3]="Personal + group(s)"; 
$LANG['joblist'][4]="Přiřazeno"; 
$LANG['joblist'][6]="Popis"; 
$LANG['joblist'][7]="Nový požadavek k této položce"; 
$LANG['joblist'][8]="Žádný úkol nebyl nalezen"; 
$LANG['joblist'][9]="Nový"; 
$LANG['joblist'][10]="Uzavřené (vyřešeno)"; 
$LANG['joblist'][11]="Otevřeno"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="No ticket in progress."; 
$LANG['joblist'][17]="Uzavřené (nevyřešeno)"; 
$LANG['joblist'][18]="Zpracování (přiřazeno)"; 
$LANG['joblist'][19]="Zpracování (naplánováno)"; 
$LANG['joblist'][21]="Zpracování"; 
$LANG['joblist'][26]="Nevyřízené"; 
$LANG['joblist'][27]="Ověření emailu"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="FAQ"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Zvolte kategorii této položky :"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Upravit tuto položku"; 
$LANG['knowbase'][9]="Smazat tuto položku"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Kořenový adresář"; 
$LANG['knowbase'][13]="Jméno kategorie"; 
$LANG['knowbase'][14]="Předmět"; 
$LANG['knowbase'][15]="Obsah"; 
$LANG['knowbase'][24]="Přístup k FAQ"; 
$LANG['knowbase'][26]="Zobrazení"; 
$LANG['knowbase'][27]="Na"; 
$LANG['knowbase'][29]="Nově přidáno"; 
$LANG['knowbase'][30]="Nejčastější otázky"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Synchronizovat již naimportované uživatele"; 
$LANG['ldap'][2]="Importovat nové uživatele"; 
$LANG['ldap'][3]="Žádní uživatelé k importu"; 
$LANG['ldap'][4]="Volba adresáře LDAP"; 
$LANG['ldap'][5]="Zvolte prosím adresář LDAP, z kterého chcete importovat uživatele"; 
$LANG['ldap'][6]="Nemohu se připojit k adresáři LDAP"; 
$LANG['ldap'][7]="V GLPI nebyl definován žádný adresář LDAP"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Test připojení k adresáři LDAP"; 
$LANG['ldap'][12]="Synchronizace"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="v GLPI"; 
$LANG['ldap'][15]="Synchronizovat"; 
$LANG['ldap'][16]="Předkonfigurace"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Replicate"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Hlavní server"; 
$LANG['ldap'][22]="Replicate(s)"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Import nových skupin"; 
$LANG['ldap'][25]="No group to be imported"; 
$LANG['ldap'][30]="Jak má být nakládáno s LDAP aliasy"; 
$LANG['ldap'][31]="Never dereferenced (default)"; 
$LANG['ldap'][32]="Always dereferenced"; 
$LANG['ldap'][33]="Dereferenced during the search (but not when locating)"; 
$LANG['ldap'][34]="Dereferenced when locating (not during the search)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Odkaz nebo jméno souboru"; 
$LANG['links'][4]="Asociovaný typ hardwaru"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Žádný odkaz nebyl definován"; 
$LANG['links'][9]="Obsah souboru"; 

$LANG['log'][1]="systém"; 
$LANG['log'][16]="plánování"; 
$LANG['log'][18]="komponenty"; 
$LANG['log'][20]="položka přidána"; 
$LANG['log'][21]="aktualizovat položku"; 
$LANG['log'][22]="Smazat položku"; 
$LANG['log'][23]="Obnovit položku"; 
$LANG['log'][24]="vyčistit položku"; 
$LANG['log'][26]="odpojit položku"; 
$LANG['log'][27]="připojení"; 
$LANG['log'][28]="Aktualizovat komponenty"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="přiřadit typ"; 
$LANG['log'][31]="Smazat typ"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="smazat odkaz s položkou"; 
$LANG['log'][34]="přidat odkaz na dodavatele"; 
$LANG['log'][35]="smazat odkaz s dodavatelem"; 
$LANG['log'][40]="Připojení IP"; 
$LANG['log'][41]="připojení selhalo"; 
$LANG['log'][42]="Rezervace"; 
$LANG['log'][44]="Hlavička"; 
$LANG['log'][45]="Úspěšné"; 
$LANG['log'][46]="Chyba"; 
$LANG['log'][48]="Přidat uživatele do skupiny"; 
$LANG['log'][49]="Smazat uživatele ze skupiny"; 
$LANG['log'][55]="Připojení"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="Přidat uživatele do objektu"; 
$LANG['log'][62]="kompletní odstranění tohoto uživatele"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="pravidlo"; 
$LANG['log'][66]="Bezpečnost"; 
$LANG['log'][67]="úprava poznámek"; 
$LANG['log'][70]="síťový port přidán"; 
$LANG['log'][71]="add several network ports"; 
$LANG['log'][73]="deletion of a network port"; 
$LANG['log'][74]="deletion of several network ports"; 
$LANG['log'][75]="network port moved"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="přidání verze"; 
$LANG['log'][83]="modification of version"; 
$LANG['log'][84]="version's deletion"; 
$LANG['log'][85]="přidání licence"; 
$LANG['log'][86]="úprava licence"; 
$LANG['log'][87]="licence's deletion"; 
$LANG['log'][88]="přidat náplně"; 
$LANG['log'][89]="přidán spotřební materiál"; 
$LANG['log'][90]="deletion of a cartridge"; 
$LANG['log'][91]="deletion of a consumable"; 
$LANG['log'][92]="restoration of a cartridge"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="aktualizace cartridge"; 
$LANG['log'][95]="instalace cartridge"; 
$LANG['log'][96]="vyjmutí cartridge"; 
$LANG['log'][97]="spotřební materiál vydán uživateli"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Poslední přihlášení"; 
$LANG['login'][1]="Znovu se přihlásit"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Přístup zamítnut"; 
$LANG['login'][6]="Přihlášení"; 
$LANG['login'][7]="Heslo"; 
$LANG['login'][8]="Prázdné přihlášení nebo heslo"; 
$LANG['login'][9]="Neautentizován"; 
$LANG['login'][10]="Autentizace"; 
$LANG['login'][11]="Uživatel není autorizován pro připojení k GLPI"; 
$LANG['login'][12]="Špatné uživatelské jméno nebo heslo."; 
$LANG['login'][13]="Políčko s heslem je prázdné"; 
$LANG['login'][14]="neznámý soubor"; 
$LANG['login'][15]="Uživatel nenalezen nebo jich bylo nalezeno více"; 
$LANG['login'][16]="neúspěšná autorizace v LDAP"; 
$LANG['login'][18]="Základ GLPI"; 
$LANG['login'][20]="Nemáte přístup k této aplikace, protože Váš účet byl deaktivován nebo odebrán"; 
$LANG['login'][21]="Testovací připojení k serveru IMAP/POP"; 
$LANG['login'][22]="Test úspěšný"; 
$LANG['login'][23]="Test selhal"; 
$LANG['login'][24]="Datum posledního přihlášení"; 
$LANG['login'][25]="Nemáte oprávnění pro připojení"; 
$LANG['login'][26]="Ve vašem prohlížeči musíte aktivovat funkce JavaScriptu"; 
$LANG['login'][27]="Pro spuštění této aplikace musíte povolit cookies"; 
$LANG['login'][30]="Změnit autentizační mechanismus"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="Autentizace v databázi GLPI"; 
$LANG['login'][33]="Autentizace na serveru IMAP/POP"; 

$LANG['mailgate'][0]="Příjemce e-mailu"; 
$LANG['mailgate'][2]="Získat úkoly emailem"; 
$LANG['mailgate'][3]="Počet dostupných a získaných zpráv"; 
$LANG['mailgate'][4]="Rozšíření mbstring nenalezeno. Upozornění týkající se použité znakové sady."; 
$LANG['mailgate'][5]="Nesprávný přiložený soubor"; 
$LANG['mailgate'][6]="Příliš veliký přiložený soubor"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Popis požadavku"; 
$LANG['mailing'][10]="Nový požadavek, následovat"; 
$LANG['mailing'][12]="Úkol přiřazen"; 
$LANG['mailing'][14]="Aktualizovat kategorii požadavku"; 
$LANG['mailing'][15]="Aktualizovat prioritu úkolu"; 
$LANG['mailing'][17]="Aktualizovat položku požadavku"; 
$LANG['mailing'][18]="Update the author of the ticket"; 
$LANG['mailing'][19]="Nová rezervace"; 
$LANG['mailing'][20]="Update the group of the ticket"; 
$LANG['mailing'][21]="Změnit ve zdroji požadavku"; 
$LANG['mailing'][23]="Úprava rezervace"; 
$LANG['mailing'][26]="Přidaný dokument:"; 
$LANG['mailing'][27]="Aktualizovat stav požadavku"; 
$LANG['mailing'][29]="Rezervace zrušena"; 
$LANG['mailing'][30]="Aktualizace úkolu"; 
$LANG['mailing'][31]="Toto je testovací email pro kontrolu systému posílání zpráv"; 
$LANG['mailing'][32]="Test mailu"; 
$LANG['mailing'][33]="Upozornění náplně"; 
$LANG['mailing'][35]="Pro tento typ spotřebního materiálu byla dosažena hodnota alarmu:"; 
$LANG['mailing'][36]="Alarm spotřebního materiálu"; 
$LANG['mailing'][37]="Smlouva zadána v čase:"; 
$LANG['mailing'][39]="Alarm smluv"; 
$LANG['mailing'][40]="Položka přišla na konci záruky:"; 
$LANG['mailing'][41]="Alarm finančních informací"; 
$LANG['mailing'][42]="Změnit hodinové ceny"; 
$LANG['mailing'][43]="Změnit pevné ceny"; 
$LANG['mailing'][44]="Změnit ceny materiálu"; 
$LANG['mailing'][45]="Změnit titul úkolu"; 
$LANG['mailing'][46]="Změnit popis úkolu"; 
$LANG['mailing'][47]="Chyba při odesílání emailu"; 
$LANG['mailing'][48]="Změnit datum založení"; 
$LANG['mailing'][49]="Změnit datum vyřešení"; 
$LANG['mailing'][50]="Změnit příjemce požadavku"; 
$LANG['mailing'][51]="Vypršená licence :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Kategorie není definována"; 
$LANG['mailing'][101]="Následující email byl povolen"; 
$LANG['mailing'][102]="Následující email byl vypnut"; 
$LANG['mailing'][104]="Trvání datového přenosu"; 
$LANG['mailing'][105]="Není přiřazeno"; 
$LANG['mailing'][107]="Nic"; 
$LANG['mailing'][109]="Žádná skupina"; 
$LANG['mailing'][110]="Neplatný email"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Počítače"; 
$LANG['Menu'][1]="Sítě"; 
$LANG['Menu'][2]="Tiskárny"; 
$LANG['Menu'][3]="Monitory"; 
$LANG['Menu'][4]="Software"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Zprávy"; 
$LANG['Menu'][11]="Nastavení"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="Statistika"; 
$LANG['Menu'][14]="Uživatelé"; 
$LANG['Menu'][15]="Administrace"; 
$LANG['Menu'][16]="Zařízení"; 
$LANG['Menu'][17]="Rezervace"; 
$LANG['Menu'][18]="Nástroje"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="FAQ"; 
$LANG['Menu'][21]="Náplně"; 
$LANG['Menu'][22]="Kontakty"; 
$LANG['Menu'][23]="Dodavatelé"; 
$LANG['Menu'][24]="Finanční informace"; 
$LANG['Menu'][25]="Smlouvy"; 
$LANG['Menu'][26]="Management"; 
$LANG['Menu'][27]="Dokumenty"; 
$LANG['Menu'][28]="Stav"; 
$LANG['Menu'][29]="Plánování"; 
$LANG['Menu'][30]="Logy"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Spotřební materiál"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefony"; 
$LANG['Menu'][35]="Profily"; 
$LANG['Menu'][36]="Skupiny"; 
$LANG['Menu'][37]="Objekty"; 
$LANG['Menu'][38]="Inventář"; 
$LANG['Menu'][39]="Receivers"; 
$LANG['Menu'][40]="Záložky"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Mikrofón"; 
$LANG['monitors'][15]="Speakery"; 
$LANG['monitors'][18]="Značky"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Velikost"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Síťový port"; 
$LANG['networking'][13]="nalezen síťový port"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Připojen k"; 
$LANG['networking'][19]="Přidat síťový port..."; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="zapnuto"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="Port"; 
$LANG['networking'][46]="Přidat více portů..."; 
$LANG['networking'][47]="Od"; 
$LANG['networking'][48]="Do"; 
$LANG['networking'][51]="Cíl sítě"; 
$LANG['networking'][55]="Přiřadit VLAN"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Zvolit MAC adresu ze seznamu níže"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Brána"; 
$LANG['networking'][60]="Maska"; 
$LANG['networking'][61]="Podsíť"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Volby importu"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Vynechat následující tagy (oddělovač $, zrušit vše)"; 
$LANG['ocsconfig'][10]="Souhrnný import"; 
$LANG['ocsconfig'][11]="Žádný import"; 
$LANG['ocsconfig'][12]="Importování jednotky"; 
$LANG['ocsconfig'][13]="Importování jednotky: vše je importováno 'tak jak je'"; 
$LANG['ocsconfig'][14]="Souhrnný import: je naimportováno vše, ale materiál je řízen gloválně (bez duplikací)"; 
$LANG['ocsconfig'][15]="Žádný import: plugin nebude tyto prvky importovat"; 
$LANG['ocsconfig'][16]="Výchozí stav"; 
$LANG['ocsconfig'][17]="Omezit import následujících značek (oddělovač $, nic pro všechny)"; 
$LANG['ocsconfig'][18]="Nejprve zkontrolujte, že jsou duplikáty řízeny pomocí OCSNG"; 
$LANG['ocsconfig'][19]="Unit import on serial number"; 
$LANG['ocsconfig'][27]="Obecné informace"; 
$LANG['ocsconfig'][36]="Modemy"; 
$LANG['ocsconfig'][37]="Porty"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registry"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Chování při odpojení"; 
$LANG['ocsconfig'][49]="Smetí"; 
$LANG['ocsconfig'][50]="Smazání"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="prázdné"; 
$LANG['ocsconfig'][57]="rovná se"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="Obsah NG OCS"; 
$LANG['ocsng'][1]="Synchronizovat již naimportované počítače"; 
$LANG['ocsng'][2]="Importovat nové počítače"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Sloučit nové počítač OCS se stávajícím počítači GLPI"; 
$LANG['ocsng'][5]="Importovat nové počítače"; 
$LANG['ocsng'][6]="Automatická aktualizace"; 
$LANG['ocsng'][7]="Importováno z OCSNG"; 
$LANG['ocsng'][8]="Import byl úspěšný"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Aktualizovat počítače"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="Importovat data do GLPI"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="Žádná položka nebyla zamknuta"; 
$LANG['ocsng'][16]="Zamknuté položky"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="Varování! Importovaná data (podívejte se na vaši konfiguraci) přepíší stávající data."; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Vynutit synchronizaci"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Ozamčené monitory"; 
$LANG['ocsng'][32]="Uzamčená zařízení"; 
$LANG['ocsng'][34]="Uzamknuté tiskárny"; 
$LANG['ocsng'][36]="Entidade de destino"; 
$LANG['ocsng'][37]="Zapnout náhled"; 
$LANG['ocsng'][38]="Vypnout náhled"; 
$LANG['ocsng'][40]="Stejné pravidlo?"; 
$LANG['ocsng'][41]="Mód ručního importu"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Agent"; 
$LANG['ocsng'][50]="Uzamknuté IP"; 
$LANG['ocsng'][52]="Uzamčený software"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Jednotka(y) uzamčena(y)"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="do"; 
$LANG['pager'][2]="od"; 
$LANG['pager'][3]="v"; 
$LANG['pager'][4]="Zobrazit"; 
$LANG['pager'][5]="položek"; 

$LANG['peripherals'][18]="Označit"; 
$LANG['peripherals'][31]="Celková správa"; 
$LANG['peripherals'][32]="Správa jednotky"; 
$LANG['peripherals'][33]="Typ managementu"; 

$LANG['phones'][18]="Označit"; 
$LANG['phones'][36]="Zdroj energie"; 
$LANG['phones'][38]="Sluchátka"; 
$LANG['phones'][39]="Speaker"; 
$LANG['phones'][40]="Počet řádků"; 

$LANG['planning'][0]="Požadovaný technik má již v tomto čase naplánovanou schůzku."; 
$LANG['planning'][1]="Chyba při přístupu k datům. Počáteční datum je novější než koncové datum"; 
$LANG['planning'][5]="Den"; 
$LANG['planning'][6]="Týden"; 
$LANG['planning'][8]="Sledování"; 
$LANG['planning'][9]="Komu"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal:// Synchronizace"; 
$LANG['planning'][14]="Měsíc"; 
$LANG['planning'][15]="Vaše plánování"; 
$LANG['planning'][16]="Informace"; 
$LANG['planning'][17]="Udělat"; 
$LANG['planning'][18]="Hotovo"; 

$LANG['plugins'][0]="Plugins list"; 
$LANG['plugins'][2]="Instalováno / nenastaveno"; 
$LANG['plugins'][3]="Instalováno / neaktivováno"; 
$LANG['plugins'][4]="Chyba / vyčistit"; 
$LANG['plugins'][5]="Non-existent function(s)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Sériová"; 
$LANG['printers'][15]="Paralelní"; 
$LANG['printers'][18]="Porty"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Číslo první stránky"; 
$LANG['printers'][31]="Vytisknutých stránek"; 

$LANG['profiles'][0]="Globální oprávnění"; 
$LANG['profiles'][1]="Práva objektu"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Vytvořit požadavek"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Zobrazit všechna oznámení"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Číst"; 
$LANG['profiles'][11]="Zapsat"; 
$LANG['profiles'][12]="Bez přístupu"; 
$LANG['profiles'][13]="Výchozí profil"; 
$LANG['profiles'][14]="Smazat požadavek"; 
$LANG['profiles'][15]="Přidat sledování všech oznámení"; 
$LANG['profiles'][16]="Vlastnit požadavek"; 
$LANG['profiles'][17]="Ukrást požadavek"; 
$LANG['profiles'][18]="Aktualizovat oznámení"; 
$LANG['profiles'][19]="Přiřadit oznámení"; 
$LANG['profiles'][20]="Prohlédnout osobní plán"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Administrace rezervace"; 
$LANG['profiles'][24]="Aktualizovat heslo"; 
$LANG['profiles'][26]="Zobrazit oznámení mé skupiny"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Rekurzivně"; 
$LANG['profiles'][29]="Dynamicky"; 
$LANG['profiles'][30]="Zobrazit informace OCSNG"; 
$LANG['profiles'][31]="Ruční synchronizace OCSNG"; 
$LANG['profiles'][32]="Podívat se na přiřazené úkoly (osobní + skupinové)"; 
$LANG['profiles'][33]="Žádný uživatel nenalezen"; 
$LANG['profiles'][34]="Nadpis"; 
$LANG['profiles'][35]="Aktualizovat všechny následovníky"; 
$LANG['profiles'][36]="See schedule of people in my groups"; 
$LANG['profiles'][37]="Výchozí objekt"; 
$LANG['profiles'][38]="Viditelnost"; 
$LANG['profiles'][39]="Přiřazení"; 
$LANG['profiles'][40]="Aktualizace"; 
$LANG['profiles'][41]="Vytvoření"; 
$LANG['profiles'][42]="Přiřazení"; 
$LANG['profiles'][43]="Uživatelské metody autentifikace a synchronizace"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hromada"; 
$LANG['registry'][2]="Cesta"; 
$LANG['registry'][3]="Klíč/hodnota"; 
$LANG['registry'][4]="Klíče registru nalezeny"; 
$LANG['registry'][5]="Žádný klíč nebyl v registru nalezen"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Osobní poznámky"; 
$LANG['reminder'][1]="Veřejné poznámky"; 
$LANG['reminder'][6]="Nová poznámka"; 
$LANG['reminder'][9]="Text"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Bez titulu"; 
$LANG['reminder'][16]="Hlavní poznámky"; 

$LANG['reports'][0]="Zvolte zprávu, kterou chcete vygenerovat"; 
$LANG['reports'][4]="Seznam hardwaru ve smlouvě"; 
$LANG['reports'][11]="Hardware součástí smlouvy"; 
$LANG['reports'][12]="Typ hardwaru"; 
$LANG['reports'][13]="Datum(y)"; 
$LANG['reports'][15]="Zobrazit zprávu"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Výchozí zpráva"; 
$LANG['reports'][27]="Podle smlouvy"; 
$LANG['reports'][28]="Podle roku"; 
$LANG['reports'][33]="Zpráva o síti"; 
$LANG['reports'][36]="Připojená zařízení"; 
$LANG['reports'][37]="Nabídky"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Podle umístění"; 
$LANG['reports'][41]="Podle hardware"; 
$LANG['reports'][42]="Podle nabidky"; 
$LANG['reports'][46]="porty switche"; 
$LANG['reports'][47]="porty zařízení"; 
$LANG['reports'][49]="Zpráva o síti podle připojení"; 
$LANG['reports'][51]="Zpráva o síti podle položek"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Zpráva o síti podle umístění"; 
$LANG['reports'][57]="Seznam materiálu"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Datum otevření"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Finanční informace o Hardware"; 
$LANG['reports'][63]="Další informace o financích (licence, náplně, spotřební materiál)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Zamluvitelných položek"; 
$LANG['reservation'][2]="Zařízení není dočasně k dispozici"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Zapsat"; 
$LANG['reservation'][9]="Zapsat položku"; 
$LANG['reservation'][16]="Do"; 
$LANG['reservation'][17]="Od"; 
$LANG['reservation'][18]="Požadovaná položka je v tomto okamžiku již rezervována."; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Upravit komentář"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="Podle týdne"; 
$LANG['reservation'][29]="Podle dne"; 
$LANG['reservation'][30]="lhůty"; 
$LANG['reservation'][31]="od"; 
$LANG['reservation'][35]="Budoucí a aktuální rezervace"; 
$LANG['reservation'][36]="Poslední rezervace"; 
$LANG['reservation'][37]="Žádné rezervace"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Odstraní všechny rezervace, na kterých se pracuje."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="je"; 
$LANG['rulesengine'][1]="není"; 
$LANG['rulesengine'][2]="obsahuje"; 
$LANG['rulesengine'][3]="neobsahuje"; 
$LANG['rulesengine'][4]="začíná s"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Kritérium"; 
$LANG['rulesengine'][7]="Akce"; 
$LANG['rulesengine'][8]="Správa pravidel"; 
$LANG['rulesengine'][9]="Odpovídající typ"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Typ akce"; 
$LANG['rulesengine'][12]="Pole"; 
$LANG['rulesengine'][13]="Hodnota"; 
$LANG['rulesengine'][14]="Podmínka"; 
$LANG['rulesengine'][15]="Důvod"; 
$LANG['rulesengine'][16]="Kritérium"; 
$LANG['rulesengine'][17]="Pravidla"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Pravidla objektu a přiřazení"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Přiřadit"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Typ pravidla"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Seznam pravidel"; 
$LANG['rulesengine'][30]="Akce"; 
$LANG['rulesengine'][33]="Vyjížděcí seznam"; 
$LANG['rulesengine'][35]="Slovník software"; 
$LANG['rulesengine'][36]="Seznam výrobců"; 
$LANG['rulesengine'][37]="Pravidla pro přiřazení programů do kategorií"; 
$LANG['rulesengine'][38]="Přepočítat"; 
$LANG['rulesengine'][40]="kategorie"; 
$LANG['rulesengine'][41]="Validace"; 
$LANG['rulesengine'][42]="A"; 
$LANG['rulesengine'][43]="NEBO"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Přiřadit: IP addresa zařízení"; 
$LANG['rulesengine'][47]="Přiřazení: jméno zařízení + doména"; 
$LANG['rulesengine'][48]="Přiřadit vybavení"; 
$LANG['rulesengine'][49]="Přiřazení: MAC adresa zařízení"; 
$LANG['rulesengine'][50]="Seznam modelů PC"; 
$LANG['rulesengine'][51]="Monitor model dictionary"; 
$LANG['rulesengine'][52]="Phone model dictionary"; 
$LANG['rulesengine'][53]="Peripheral model dictionary"; 
$LANG['rulesengine'][54]="Printer model dictionary"; 
$LANG['rulesengine'][55]="Networking model dictionary"; 
$LANG['rulesengine'][56]="Modely"; 
$LANG['rulesengine'][60]="Seznam typů PC"; 
$LANG['rulesengine'][61]="Monitor type dictionary"; 
$LANG['rulesengine'][62]="Phone type dictionary"; 
$LANG['rulesengine'][63]="Peripheral type dictionary"; 
$LANG['rulesengine'][64]="Printer type dictionary"; 
$LANG['rulesengine'][65]="Seznam síťových zařízení"; 
$LANG['rulesengine'][66]="Typy"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Service Pack dictionary"; 
$LANG['rulesengine'][69]="OS versions dictionary"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Rename based on dictionary"; 
$LANG['rulesengine'][77]="Slovníky"; 
$LANG['rulesengine'][78]="Verze"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Globální slovník"; 
$LANG['rulesengine'][81]="Rule results"; 
$LANG['rulesengine'][82]="Result details"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Test rules engine"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software deleted by GLPI dictionary"; 
$LANG['rulesengine'][90]="Ve zpracování..."; 
$LANG['rulesengine'][91]="Dokončeno."; 
$LANG['rulesengine'][92]="Warning before running rename based on the dictionary"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Volba výrobce"; 
$LANG['rulesengine'][96]="Rename based on the manufacturer(s)dictionary<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="No element to be tested"; 
$LANG['rulesengine'][100]="Cache informace"; 
$LANG['rulesengine'][102]="Rule name"; 
$LANG['rulesengine'][103]="Objects in cache"; 
$LANG['rulesengine'][104]="Původní hodnota"; 
$LANG['rulesengine'][105]="Modified value"; 
$LANG['rulesengine'][106]="Unchanged"; 
$LANG['rulesengine'][107]="Neaktivní"; 
$LANG['rulesengine'][108]="originál"; 
$LANG['rulesengine'][110]="Rights assignment"; 
$LANG['rulesengine'][111]="Přiřazení objektů"; 
$LANG['rulesengine'][112]="Rights and entities assignment"; 
$LANG['rulesengine'][120]="Zastavit na prvním vybraném pravidlu."; 
$LANG['rulesengine'][121]="Vsechna pravidla jsou prováděna."; 
$LANG['rulesengine'][122]="Pravidla jsou použita pro následující."; 
$LANG['rulesengine'][130]="Objekt z LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Hledat"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="obsahuje"; 
$LANG['search'][4]="seřazeno dle"; 
$LANG['search'][8]="Počáteční datum"; 
$LANG['search'][9]="Datum ukončení"; 
$LANG['search'][10]="v"; 
$LANG['search'][11]="Položek nalezeno"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Položka nebyla nalezena"; 
$LANG['search'][16]="Nejmenší"; 
$LANG['search'][17]="Přidat vyhledávací kritérium"; 
$LANG['search'][18]="Kritéria mazání a vyhledávání"; 
$LANG['search'][19]="Přidat globální kritéria vyhledávání"; 
$LANG['search'][20]="Přidat globální kritéria vyhledávání"; 

$LANG['setup'][0]="Rozbalovací nabídky"; 
$LANG['setup'][2]="Přidat uživatele..."; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Typy počítačů"; 
$LANG['setup'][5]="Operační systémy"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Síťová rozhraní"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Přihlášení"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Zvolte jazyk"; 
$LANG['setup'][42]="Typy sítí"; 
$LANG['setup'][43]="Typy tiskáren"; 
$LANG['setup'][44]="Typy monitoru"; 
$LANG['setup'][45]="Typ skříně"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Zvolte kategorii ke konfiguraci"; 
$LANG['setup'][63]="Varování: měli byste odstranit hlavičku použitou pro  jednu nebo více položek"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="Také můžete nahradit všechny události této hlavičky jinou:"; 
$LANG['setup'][67]="Externí autentizace"; 
$LANG['setup'][69]="typy zařízení"; 
$LANG['setup'][70]="Obecné nastavení"; 
$LANG['setup'][71]="Firmware"; 
$LANG['setup'][73]="Cíl sítě"; 
$LANG['setup'][74]="Toto umístění nelze smazat, protože má pod-umístění"; 
$LANG['setup'][75]="Jako potomek"; 
$LANG['setup'][79]="Kategorie požadavků"; 
$LANG['setup'][80]="Označení typu třetích stran"; 
$LANG['setup'][81]="Hlavičky dokumentu"; 
$LANG['setup'][82]="Typ spojení"; 
$LANG['setup'][83]="Stav položky"; 
$LANG['setup'][84]="Typ náplně"; 
$LANG['setup'][85]="Typ smlouvy"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Síť"; 
$LANG['setup'][89]="Doména"; 
$LANG['setup'][90]="VLANy"; 
$LANG['setup'][91]="Modely počítačů"; 
$LANG['setup'][92]="Typ spotřebního materiálu"; 
$LANG['setup'][93]="Rozhraní pevného disku"; 
$LANG['setup'][94]="Modely monitorů"; 
$LANG['setup'][95]="Modely sítě"; 
$LANG['setup'][96]="Modely tiskáren"; 
$LANG['setup'][97]="Modely periférií"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Úroveň logování"; 
$LANG['setup'][103]="1- Kritické (pouze chyba přihlášení)"; 
$LANG['setup'][104]="2- Vážné (Nepoužívá se)"; 
$LANG['setup'][105]="3- Důležité (úspěšná přihlášení)"; 
$LANG['setup'][106]="4- Poznámky (Přidat, smazat, sledování)"; 
$LANG['setup'][107]="5- Komplet (Vše)"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Show new tickets on the home page"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Výchozí jazyk"; 
$LANG['setup'][114]="Barvy priority"; 
$LANG['setup'][115]="Výchozí práh pro náplně a množství spotřebního materiálu"; 
$LANG['setup'][116]="Automatické přiřazení oznámení technikovi"; 
$LANG['setup'][117]="Autorizovat anonymní pohled na FAQ"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Automaticky přidat uživatele z externího autentizačního zdroje"; 
$LANG['setup'][125]="... Z externího zdroje"; 
$LANG['setup'][126]="Automaticky přidat uživatele z externího zdroje"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Formát data"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="Aktivovat mód OCSNG"; 
$LANG['setup'][134]="Mód OCSNG"; 
$LANG['setup'][135]="Normální"; 
$LANG['setup'][136]="Překlad"; 
$LANG['setup'][137]="Ladit"; 
$LANG['setup'][138]="Mód použít GLPI"; 
$LANG['setup'][139]="Obecný"; 
$LANG['setup'][140]="Typy"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Pokrok za hodinu"; 
$LANG['setup'][149]="Počet desetinných míst v částkách"; 
$LANG['setup'][150]="Number Format"; 
$LANG['setup'][154]="ZákladDN"; 
$LANG['setup'][155]="rootdn (pro anonymní přiřazení)"; 
$LANG['setup'][156]="Projít (pro ne-anonymní přiřazení)"; 
$LANG['setup'][157]="Rozšíření LDAP vašeho překladače PHP není nainstalováno"; 
$LANG['setup'][158]="Není možné vytvořit připojení k externímu zdroji LDAP"; 
$LANG['setup'][159]="Filtr připojení"; 
$LANG['setup'][162]="Konfigurace IMAP/POP"; 
$LANG['setup'][164]="Jméno počítače IMAP/POP (uživatelský email bude mít tento tvar login@tentohostitel)"; 
$LANG['setup'][165]="Váš překladač PHP byl zkompilován bez funkcí IMAP"; 
$LANG['setup'][166]="Není možné vytvořit připojení k externímu zdroji IMAP/POP"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Volby připojení"; 
$LANG['setup'][169]="E-mail složka (volitelné, většinou INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Port (volitelně)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="Počítač CAS"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Kořenový adresář (volitelný)"; 
$LANG['setup'][177]="Konfigurace CAS"; 
$LANG['setup'][178]="Rozšíření CURL nebo DOMXML vašeho PHP není nainstalováno"; 
$LANG['setup'][179]="Není možné použít připojení k externímu zdroji CAS"; 
$LANG['setup'][180]="Použít TLS"; 
$LANG['setup'][181]="ldap_start_tls neexistuje"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Časová zóna"; 
$LANG['setup'][190]="x509 certifikát"; 
$LANG['setup'][191]="e-mail atribut pro x509"; 
$LANG['setup'][192]="Zapnuto"; 
$LANG['setup'][193]="Proměnná, které obsahuje login v poli _SERVER"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Zachovat stav"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Zkopírovat stav počítače"; 
$LANG['setup'][198]="Set status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Email správce"; 
$LANG['setup'][204]="Podpis emailu"; 
$LANG['setup'][205]="Poslat email administrátorovi"; 
$LANG['setup'][206]="Chyba při odesílání emailu administrátorovi"; 
$LANG['setup'][207]="E-mail Administrátora (pokud je třeba)"; 
$LANG['setup'][217]="Funkce PHP mail je neznámá nebo není ve vašem systému aktivní"; 
$LANG['setup'][218]="Je potřeba použít server SMTP"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Omezení plánovací tabulky"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Přihlašovací pole"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Use a SMTP server to send emails"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Password (optional)"; 
$LANG['setup'][236]="Dřívější technik, který měl na starosti požadavek"; 
$LANG['setup'][237]="Administrator"; 
$LANG['setup'][239]="Technik, který má tento úkol na starost"; 
$LANG['setup'][240]="Volby upozornění"; 
$LANG['setup'][241]="Žádná osobní kritéria. Vytvořit osobní parametry?"; 
$LANG['setup'][242]="Možnosti alarmu"; 
$LANG['setup'][243]="Alarm spotřebního materiálu"; 
$LANG['setup'][244]="Alarm na kazetách"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Alarm na smlouvách"; 
$LANG['setup'][247]="Alarm při finanční informaci"; 
$LANG['setup'][248]="Skupina přiřazená k  danému úkolu"; 
$LANG['setup'][249]="Requester group"; 
$LANG['setup'][250]="Výchozí seznam hledaných polí"; 
$LANG['setup'][252]="Zvolte výchozí položky, které zobrazit"; 
$LANG['setup'][253]="Filtr prohledávání ve skupinách"; 
$LANG['setup'][254]="Typ hledání"; 
$LANG['setup'][255]="Atribut skupiny obsahující její členy"; 
$LANG['setup'][256]="V uživatelích"; 
$LANG['setup'][257]="Ve skupinách"; 
$LANG['setup'][258]="Uživatelé a skupiny"; 
$LANG['setup'][259]="Patří do skupin"; 
$LANG['setup'][260]="Atribut uživatele obsahuje vlastní skupinu"; 
$LANG['setup'][261]="Doménová skupina"; 
$LANG['setup'][262]="Použít DN ve vyhledávání"; 
$LANG['setup'][263]="Vyhledávací filtr uživatelů"; 
$LANG['setup'][264]="Alarmy prošlých licencí"; 
$LANG['setup'][271]="Omezit správu sledování"; 
$LANG['setup'][272]="Omezit řízení zařízení"; 
$LANG['setup'][273]="Omezit správu telefonu"; 
$LANG['setup'][274]="ručně přidat"; 
$LANG['setup'][275]="Omezit správu tiskárny"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Zkopírovat"; 
$LANG['setup'][284]="Vyčistit"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Zkontrolovat dostupnost nové verze"; 
$LANG['setup'][301]="Nová verze k dispozici:"; 
$LANG['setup'][302]="You will find it on the GLPI-PROJECT.org site"; 
$LANG['setup'][303]="Máte poslední verzi"; 
$LANG['setup'][304]="Spojení selhalo. Pokud používáte proxy server, nastavte jej."; 
$LANG['setup'][305]="Denně"; 
$LANG['setup'][306]="Kontrola aktualizací"; 
$LANG['setup'][307]="Nikdy"; 
$LANG['setup'][308]="Každý týden"; 
$LANG['setup'][309]="Každý měsíc"; 
$LANG['setup'][310]="Nelze se připojit k adrese."; 
$LANG['setup'][311]="Chyba při připojení k serveru proxy"; 
$LANG['setup'][312]="No data available on the web site"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Spojit s položkami pro vytváření požadavků"; 
$LANG['setup'][351]="Všechny položky"; 
$LANG['setup'][352]="Spojitelné položky s požadavkem"; 
$LANG['setup'][360]="Automatická políčka (označená *)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Výchozí hlavička při přidání dokumentu k úkolu"; 
$LANG['setup'][503]="Modely telefonů"; 
$LANG['setup'][504]="Typy telefonů"; 
$LANG['setup'][505]="Typ zdroje energie u telefonů"; 
$LANG['setup'][601]="Hodnota LDAP"; 
$LANG['setup'][602]="Spojení s OCSNG databází"; 
$LANG['setup'][603]="Přidat uživatele"; 
$LANG['setup'][604]="Přiřadit ke skupině"; 
$LANG['setup'][606]="Není možno přidat. Uživatel již existuje."; 
$LANG['setup'][607]="Přiřadit k profilu"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Compulsory title of the ticket"; 
$LANG['setup'][611]="Compulsory ticket content"; 
$LANG['setup'][612]="Compulsory ticket category"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Odkaz"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Obecné"; 
$LANG['setup'][704]="Upozornění"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql replikace"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Databáze"; 
$LANG['setup'][803]="Rozdíl mezi master a slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slave database out of sync!"; 
$LANG['setup'][809]="MySQL replika: jen číst"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Purchase version"; 
$LANG['software'][2]="Použít verzi"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Neomezeně"; 
$LANG['software'][5]="Verze"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Přidat verzi"; 
$LANG['software'][8]="Přidat licenci"; 
$LANG['software'][11]="Licence"; 
$LANG['software'][17]="Nainstalované programy"; 
$LANG['software'][19]="Instalace"; 
$LANG['software'][20]="Zbývající"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Aktualizace"; 
$LANG['software'][30]="Type of license"; 
$LANG['software'][32]="Platnost"; 
$LANG['software'][44]="Instalovat software"; 
$LANG['software'][45]="Odinstalovat program"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Slučuji"; 
$LANG['software'][48]="Spojit"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Přiřazeno k počítači"; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Kategorie programů"; 

$LANG['state'][0]="Stav"; 
$LANG['state'][6]="Typ položky"; 
$LANG['state'][7]="Položky nebyly nalezeny"; 
$LANG['state'][11]="Souhrn"; 

$LANG['stats'][0]="Zvolte zobrazenou statistiku"; 
$LANG['stats'][1]="Globální"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Dle položky"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Průměrná doba řešení problému"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Počet vyřešených požadavků"; 
$LANG['stats'][13]="Počet požadavků"; 
$LANG['stats'][15]="Průměrná doba řešení problému"; 
$LANG['stats'][16]="Jméno technika"; 
$LANG['stats'][20]="Uživatelské jméno"; 
$LANG['stats'][23]="Žádná statistika není k dispozici"; 
$LANG['stats'][25]="Průměrná (skutečná) doba trvání požadavku"; 
$LANG['stats'][27]="Celková (skutečná) doba trvání úkolu"; 
$LANG['stats'][30]="Průměrná doba trvání odpovědi na požadavek"; 
$LANG['stats'][31]="Datum(y)"; 
$LANG['stats'][33]="Minut"; 
$LANG['stats'][34]="Sekund"; 
$LANG['stats'][35]="Úkol(y)"; 
$LANG['stats'][44]="Jméno dodavatele"; 
$LANG['stats'][45]="Podle hardwaru"; 
$LANG['stats'][47]="Podle požadavků"; 
$LANG['stats'][48]="(přiřazeno)"; 
$LANG['stats'][49]="(sledovat)"; 

$LANG['title'][5]="Databáze znalostí"; 
$LANG['title'][6]="Vytváření sítě"; 
$LANG['title'][9]="Stav položky"; 
$LANG['title'][10]="Sledování úkolu"; 
$LANG['title'][13]="Informace o uživateli"; 
$LANG['title'][14]="Externí autentizační zdroje"; 
$LANG['title'][24]="Podpora"; 
$LANG['title'][26]="Hlavní"; 
$LANG['title'][27]="Připojení"; 
$LANG['title'][28]="Úkoly"; 
$LANG['title'][30]="Komponenty"; 
$LANG['title'][33]="Externí odkazy"; 
$LANG['title'][34]="Spojení"; 
$LANG['title'][37]="Poznámky"; 
$LANG['title'][38]="Historický"; 
$LANG['title'][40]="Veřejné a osobní poznámky"; 
$LANG['title'][42]="Hromadná úprava"; 
$LANG['title'][43]="Registr"; 

$LANG['tracking'][1]="Má zařízení"; 
$LANG['tracking'][2]="Nebo kompletní vyhledávání"; 
$LANG['tracking'][3]="Špatné datum. Akce zrušena."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="Váš požadavek je bez popisu, zkuste to prosím znovu."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Požadavek na dokument"; 
$LANG['tracking'][29]="Číslo"; 
$LANG['tracking'][30]="Nová"; 
$LANG['tracking'][31]="Zpracování (přiřazeno)"; 
$LANG['tracking'][32]="Zpracování (naplánováno)"; 
$LANG['tracking'][34]="Přímo"; 
$LANG['tracking'][35]="Zapsáno"; 
$LANG['tracking'][37]="Uchovat požadavky při odstranění hardwaru z inventáře"; 
$LANG['tracking'][38]="Email byl odleslán na"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Přemístění"; 
$LANG['transfer'][3]="Není-li použito"; 
$LANG['transfer'][4]="Vyčistit seznam prvků určených k přenosu"; 
$LANG['transfer'][5]="V přidávání položek určených k přesunu můžete dál pokračovat nebo můžete nyní přesunout tyto položky."; 
$LANG['transfer'][6]="Přemýšlejte o provedení zálohy před vlastním přesunem položek."; 
$LANG['transfer'][7]="Položek k přesunu"; 
$LANG['transfer'][8]="Mód přesunu"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Chyba při aktualizaci databáze"; 
$LANG['update'][91]="Varování!"; 
$LANG['update'][92]="Dojde k aktualizaci databáze GLPI pojmenované :"; 
$LANG['update'][93]="Připojení k databázi bylo úspěšné"; 
$LANG['update'][94]="Aktualizace úspěšná, vaše databáze je aktuální"; 
$LANG['update'][95]="Připojení do databáze selhalo, ověřte parametry připojení obsažené v souboru config_db.php"; 
$LANG['update'][96]="Nyní mají všichni administrátoři práva 'super-admin'. Tento nový typ uživatele byl automaticky přidán."; 
$LANG['update'][105]="Takto není možné dokončit aktualizaci!!"; 
$LANG['update'][106]="Návrat zpět do GLPI"; 
$LANG['update'][107]="Pro aktualizaci obsahu vaší databáze musíte pokračovat"; 
$LANG['update'][130]="Aktualizace umístění"; 
$LANG['update'][131]="Nová struktura je hierarchická"; 
$LANG['update'][132]="Pokud jste použili oddělovací značku, můžete jí nastavit a tak automatizovat proces generování nové struktury."; 
$LANG['update'][133]="Také můžete určit umístění rootu, které bude obsahovat všechna vytvořená umístění."; 
$LANG['update'][134]="Znak rozdělení"; 
$LANG['update'][135]="Umístění kořenového adresáře"; 
$LANG['update'][136]="Toto je nová hierarchie. To je v pořádku, můžete ji potvrdit."; 
$LANG['update'][137]="Nová struktura"; 
$LANG['update'][138]="Aktuální umístění"; 
$LANG['update'][139]="Optimizing tables"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Title"; 
$LANG['users'][2]="Kategorie"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>